colour_hdri.utilities — Colour - HDRI 0.1.0 documentation

# Source code for colour_hdri.utilities

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import
    from .common import (
        linear_conversion,
        vivification,
        vivified_to_dict,
        path_exists,
        filter_files)
    from .exif import (
        EXIF_EXECUTABLE,
        parse_exif_data,
        read_exif_tags,
        copy_exif_tags,
        update_exif_tags,
        delete_exif_tags,
        read_exif_tag,
        write_exif_tag)
    from .exposure import (
        exposure_value,
        adjust_exposure,
        average_luminance)
    from .image import (
        Metadata,
        Image,
        ImageStack)

    __all__ = []
    __all__ += [
        'linear_conversion',
        'vivification',
        'vivified_to_dict',
        'path_exists',
        'filter_files']
    __all__ += [
        'EXIF_EXECUTABLE',
        'parse_exif_data',
        'read_exif_tags',
        'copy_exif_tags',
        'update_exif_tags',
        'delete_exif_tags',
        'read_exif_tag',
        'write_exif_tag']
    __all__ += [
        'exposure_value',
        'adjust_exposure',
        'average_luminance']
    __all__ += [
        'Metadata',
        'Image',
        'ImageStack']